@@ -1,9 +1,30 @@
 from types import SimpleNamespace
-from typing import List, Optional
+from typing import List, Optional, final
 
 from .base import BaseService
 
 
+class PrintMixin:
+    @final
+    def __repr__(self) -> str:
+        object_methods = [
+            method_name
+            for method_name in dir(self)
+            if callable(getattr(self, method_name)) and not method_name.startswith("_")
+        ]
+        object_attributes = [
+            attribute_name
+            for attribute_name in dir(self)
+            if not callable(getattr(self, attribute_name))
+            and not attribute_name.startswith("_")
+        ]
+        return f"{self.__class__.__name__}(attributes: {object_attributes}, methods: {object_methods})"
+
+    @final
+    def __str__(self) -> str:
+        return self.__repr__()
+
+
 class CommonMixin:
     """Mixin with common methods for services."""
 
